@@ -162,13 +162,17 @@ check_goos_goarch() {
 	linux/amd64) return 0 ;;
 	linux/arm) return 0 ;;
 	linux/arm64) return 0 ;;
+	linux/mips64) return 0 ;;
+	linux/mips64le) return 0 ;;
 	linux/ppc64) return 0 ;;
 	linux/ppc64le) return 0 ;;
+	linux/riscv64) return 0 ;;
 	linux/s390x) return 0 ;;
 	openbsd/386) return 0 ;;
 	openbsd/amd64) return 0 ;;
 	openbsd/arm) return 0 ;;
 	openbsd/arm64) return 0 ;;
+	openbsd/mips64) return 0 ;;
 	solaris/amd64) return 0 ;;
 	windows/386) return 0 ;;
 	windows/amd64) return 0 ;;
